@@ -27,7 +27,8 @@ class ops_partials_edge<double, var_value<Op>,
         operands_(ops) {}
 
  private:
-  template <typename, typename, typename, typename, typename, typename>
+  template <typename, typename, typename, typename, typename, typename,
+            typename, typename, typename>
   friend class stan::math::operands_and_partials;
   var_value<Op> operands_;
   static constexpr int size() noexcept { return 0; }
